---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Traceback**
If applicable, add any exception tracebacks.

**Installed packages**
If applicable, add a list of installed packages. Obtain the list with `pip freeze`.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment (please complete the following information):**
 - Host OS: [e.g. Windows 10, Ubuntu 20.04]
 - Acconeer hardware: [e.g. XM112, Raspberry Pi XC112 + XR112]
 - Acconeer software version: [e.g. 2.0.0]
 - Exploration version: [e.g. e78bdc6 or v3.0.2]

**Additional context**
Add any other context about the problem here.
